Module: OpenTelemetry::Instrumentation

Extended by:
Instrumentation
Included in:
Instrumentation
Defined in:
lib/opentelemetry/instrumentation.rb,
lib/opentelemetry/instrumentation/registry.rb,
lib/opentelemetry/instrumentation/registry/version.rb

Overview

Instrumentation should be able to handle the case when the library is not installed on a user's system.

Defined Under Namespace

Classes: Registry

Instance Method Summary collapse

Instance Method Details

#registryRegistry

Returns registry containing all known instrumentation.

Returns:

  • (Registry)

    registry containing all known instrumentation



22
23
24
# File 'lib/opentelemetry/instrumentation.rb', line 22

def registry
  @registry ||= Registry.new
end