Module: OpenTelemetry::Instrumentation
- Extended by:
- Instrumentation
- Included in:
- Instrumentation
- Defined in:
- lib/opentelemetry/instrumentation.rb,
lib/opentelemetry/instrumentation/registry.rb,
lib/opentelemetry/instrumentation/registry/version.rb
Overview
Instrumentation should be able to handle the case when the library is not installed on a user's system.
Defined Under Namespace
Classes: Registry
Instance Method Summary collapse
-
#registry ⇒ Registry
Registry containing all known instrumentation.